SystemOrganization addCategory: #ConfigurationOfRoassal!

Object subclass: #ConfigurationOfRoassal
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfRoassal'!

!ConfigurationOfRoassal class methodsFor: 'development support' stamp: ''!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfRoassal class methodsFor: 'metacello tool support' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfRoassal class methodsFor: 'accessing' stamp: ''!
project

	^self new project! !

!ConfigurationOfRoassal class methodsFor: 'development support' stamp: ''!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: ''!
baseline10: spec
	<version: '0.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec group: 'default' with: #(#Roassal ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/18/2012 14:16'!
baseline11: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec package: 'Roassal-Morphic'.
		spec group: 'default' with: #(#Roassal ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/18/2012 15:17'!
baseline12: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec package: #RoassalMorphic.
		spec group: 'default' with: #(#Roassal #RoassalMorphic). ].
! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 5/7/2012 12:23'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.150'.
! !

!ConfigurationOfRoassal methodsFor: 'accessing' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: ''!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.62'.
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/28/2012 17:17'!
version0129: spec
	<version: '0.129' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.128 : Removed a platform dependent method
0.129 : An edge with a null extremity cannot be added in the builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/28/2012 17:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.141';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/30/2012 09:38'!
version0130: spec
	<version: '0.130' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.129 : An edge with a null extremity cannot be added in the builder
0.130 : Added method complexity example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/30/2012 09:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.143';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/30/2012 17:30'!
version0131: spec
	<version: '0.131' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.130 : Added method complexity example
0.131 : No popup and ViewStack that works well!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/30/2012 17:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.144';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 16:39'!
version0132: spec
	<version: '0.132' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.131 : No popup and ViewStack that works well!!
0.132 : Fixed bug with misplaced popup'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 16:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.145';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 17:33'!
version0133: spec
	<version: '0.133' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.132 : Fixed bug with misplaced popup
0.133 : Added command example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 17:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.146';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 17:43'!
version0134: spec
	<version: '0.134' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.133 : Added command example
0.134 : Added zoom. Try: ROMondrianExample new command'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 17:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 19:25'!
version0135: spec
	<version: '0.135' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.134 : Added zoom. Try: ROMondrianExample new command
0.135 : Added an easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 19:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.10'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 09:43'!
version0136: spec
	<version: '0.136' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.135 : Added an easel
0.136 : Added a zoom in and zoom out and find in the easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 09:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.11'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 10:41'!
version0137: spec
	<version: '0.137' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.136 : Added a zoom in and zoom out and find in the easel
0.137 : removed allPopups since it is not necessary and caused problem on VW (because of the WeakSet)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 10:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.148';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.12'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 10:51'!
version0138: spec
	<version: '0.138' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.137 : removed allPopups since it is not necessary and caused problem on VW (because of the WeakSet)
0.138 : Added a highlight when finding a node in the easel.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 10:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.148';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.13'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 09:56'!
version0139: spec
	<version: '0.139' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.138 : Added a highlight when finding a node in the easel.
0.139 : bug fixed with popupView:
0.139 : Worked on the examples and fixed what Vanessa asked for'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 09:56'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.150';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 16:47'!
version0140: spec
	<version: '0.140' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.139 : Worked on the examples and fixed what Vanessa asked for
0.140 : added a rotimeorganizer. Useful for the VW port'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 16:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.151';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 17:11'!
version0141: spec
	<version: '0.141' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.140 : added a rotimeorganizer. Useful for the VW port
0.141 : Move a class to the right package.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 17:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.152';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:24'!
version0142: spec
	<version: '0.142' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.141 : Move a class to the right package.
0.142 : Added RODummyNode, else Sugiyama does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.153';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:36'!
version0143: spec
	<version: '0.143' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.142 : Added RODummyNode, else Sugiyama does not work
0.143 : Added an example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.154';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:40'!
version0144: spec
	<version: '0.144' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.143 : Added an example
0.144 : minor fix in the sugiyama layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:40'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.155';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/4/2012 11:05'!
version0145: spec
	<version: '0.145' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.144 : minor fix in the sugiyama layout
0.145 : Worked on the tutorial. Added a ROSequenceInteraction'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/4/2012 11:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.156';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/4/2012 11:32'!
version0146: spec
	<version: '0.146' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.145 : Worked on the tutorial. Added a ROSequenceInteraction
0.146 : Fixed the tests for ROSequenceInteraction'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/4/2012 11:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.157';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/6/2012 10:35'!
version0147: spec
	<version: '0.147' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.146 : Fixed the tests for ROSequenceInteraction
0.147 : Bug fixed with clickToFocus'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/6/2012 10:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.158';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 09:36'!
version0148: spec
	<version: '0.148' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.147 : Bug fixed with clickToFocus
0.148 : Minor cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 09:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.159';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 12:20'!
version0149: spec
	<version: '0.149' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.148 : Minor cleaning
0.149 : Renamed RODecorator into ROShape. It makes sense since RODecorator is not really the implementation of the decorator pattern anyway. Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 12:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.160';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 18:14'!
version0150: spec
	<version: '0.150' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.149 : Renamed RODecorator into ROShape. It makes sense since RODecorator is not really the implementation of the decorator pattern anyway. Thanks Doru!!
0.150 : remove a super initialize in ROEvent.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 18:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.161';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version10: spec
	<version: '0.0' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:19'!
version1100: spec
	<version: '0.100' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.99 : Put Morphic into a new package
0.100 : Added the Morphic package in the configuration'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:19'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.112'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:30'!
version1101: spec
	<version: '0.101' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.100 : Added the Morphic package in the configuration
0.101 : Added the class ROIdentityMatrix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.113';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:41'!
version1102: spec
	<version: '0.102' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.101 : Added the class ROIdentityMatrix
0.102 : Removed use of asString'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.114';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:45'!
version1103: spec
	<version: '0.103' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.102 : Removed use of asString
0.103 : Removed noneSatisfy:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.115';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:47'!
version1104: spec
	<version: '0.104' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.103 : Removed noneSatisfy:
0.104 : Removed reference to AssertionError'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.116';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:59'!
version1105: spec
	<version: '0.105' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.104 : Removed reference to AssertionError
0.105 : Roassal does not depend on TextStyle but ROFontOrganizer instead. The call to valuesDo: has been removed. This help make VW happy.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.117';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 15:08'!
version1106: spec
	<version: '0.106' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.105 : Roassal does not depend on TextStyle but ROFontOrganizer instead. The call to valuesDo: has been removed. This help make VW happy.
0.106 : Superclass of ROMondrianBuilder es ROObject ahora'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 15:08'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.118';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 15:19'!
version1107: spec
	<version: '0.107' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.106 : Superclass of ROMondrianBuilder es ROObject ahora
0.107 : Renamed the package Roassal-Morphic into RoassalMorphic'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 15:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.119';
			package: 'Roassal-Morphic' with: 'Roassal-Morphic-AlexandreBergel.3'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 15:22'!
version1108: spec
	<version: '0.108' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.107 : Renamed the package Roassal-Morphic into RoassalMorphic
0.108 : Renamed package Roassal-Morphic into RoassalMorphic'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 15:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.119';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 15:37'!
version1109: spec
	<version: '0.109' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.108 : Renamed package Roassal-Morphic into RoassalMorphic
0.109 : added missing #is: on ROAbstractView. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 15:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.120';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version110: spec
	<version: '0.10' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.11'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 15:42'!
version1110: spec
	<version: '0.110' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.109 : added missing #is: on ROAbstractView. 
0.110 : Removed select:thenDo: and #ifEmpty:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 15:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.121';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.1'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 15:51'!
version1111: spec
	<version: '0.111' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.110 : Removed select:thenDo: and #ifEmpty:
0.111 : added ROFontOrganizer and ROFontOrganizerMorphic. Did a bit more cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 15:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.122';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 16:01'!
version1112: spec
	<version: '0.112' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.111 : added ROFontOrganizer and ROFontOrganizerMorphic. Did a bit more cleaning
0.112 : removed ifEmpty: isUnary and the call #value to a ROEdge'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 16:01'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.123';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 16:07'!
version1113: spec
	<version: '0.113' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.112 : removed ifEmpty: isUnary and the call #value to a ROEdge
0.113 : Removed call to className'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 16:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.124';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 16:30'!
version1114: spec
	<version: '0.114' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.113 : Removed call to className
0.114 :
0.114 :
0.114 : removed infinity'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 16:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.126';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 16:36'!
version1115: spec
	<version: '0.115' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.114 : removed infinity
0.115 : Removed with:with:with:with:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 16:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.127';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 08:46'!
version1116: spec
	<version: '0.116' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.115 : Removed with:with:with:with:
0.116 : Changed 1e308 for 1e10, this makes VW happy'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 08:46'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.128';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 10:07'!
version1117: spec
	<version: '0.117' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.116 : Changed 1e308 for 1e10, this makes VW happy
0.117 : removed brocken tests. Apparently VW does not know about expectedFailures'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 10:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.129';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 10:26'!
version1118: spec
	<version: '0.118' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.117 : removed brocken tests. Apparently VW does not know about expectedFailures
0.118 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 10:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.130';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 11:04'!
version1119: spec
	<version: '0.119' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.118 : Cleaning
0.119 : Cleaning.... Removed all the expected failures because VW does not support this'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 11:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.131';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.2'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version111: spec
	<version: '0.11' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.12'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 12:09'!
version1120: spec
	<version: '0.120' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.119 : Cleaning.... Removed all the expected failures because VW does not support this
0.120 : Added ROAbstractCanvas and renamed ROCanvas into ROPharoCanvas'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 12:09'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.132';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.3'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 12:22'!
version1121: spec
	<version: '0.121' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.120 : Added ROAbstractCanvas and renamed ROCanvas into ROPharoCanvas
0.121 : Moved some methods up to ROAbstactCanvas and created a test for this'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 12:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.133';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.4'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/19/2012 12:30'!
version1122: spec
	<version: '0.122' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.121 : Moved some methods up to ROAbstactCanvas and created a test for this
0.122 : removed a dependency '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/19/2012 12:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.134';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.4'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/23/2012 17:37'!
version1123: spec
	<version: '0.123' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.122 : removed a dependency 
0.123 : Added RONativeWidgetFactory to make sure that a view opens the right native widget, independently if it runs on Pharo or VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/23/2012 17:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.135';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.5'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/25/2012 16:00'!
version1124: spec
	<version: '0.124' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.123 : Added RONativeWidgetFactory to make sure that a view opens the right native widget, independently if it runs on Pharo or VW
0.124 : Moved all the tests that use encodingForm: in the Morphic package. Since this cannot be easily ported in VisualWorks.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/25/2012 16:00'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.136';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.6'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/26/2012 17:11'!
version1125: spec
	<version: '0.125' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.124 : Moved all the tests that use encodingForm: in the Morphic package. Since this cannot be easily ported in VisualWorks.
0.125 : extracted MorphMenu from the core. the NativeWidget class has been extended.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/26/2012 17:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.137';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.7'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/27/2012 18:39'!
version1126: spec
	<version: '0.126' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.125 : extracted MorphMenu from the core. the NativeWidget class has been extended.
0.126 : ROLabel now supports multiline text'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/27/2012 18:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.138';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/27/2012 18:56'!
version1127: spec
	<version: '0.127' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.126 : ROLabel now supports multiline text
0.127 : Remove the call to linesDo: since it is not supported in VW.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/27/2012 18:56'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.139';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/27/2012 20:22'!
version1128: spec
	<version: '0.128' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.127 : Remove the call to linesDo: since it is not supported in VW.
0.128 : Removed a platform dependent method'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/27/2012 20:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.140';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version112: spec
	<version: '0.12' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.13'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version113: spec
	<version: '0.13' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version114: spec
	<version: '0.14' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version115: spec
	<version: '0.15' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.0 : New tests, Nesting works better (elementAt:)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 16:37'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version116: spec
	<version: '0.16' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.15 : contains
0.16 : Added ROCountingNullCanvas'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:03'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version117: spec
	<version: '0.17' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.16 : Added ROCountingNullCanvas
0.17 : removed the use of pink'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:08'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version118: spec
	<version: '0.18' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.17 : removed the use of pink
0.18 : All tests are green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:15'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.20'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version119: spec
	<version: '0.19' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.18 : All tests are green
0.19 : added growable and layout (copied from Mondrian)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:40'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.21'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version11: spec
	<version: '0.1' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.15 : contains'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:00'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version120: spec
	<version: '0.20' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.19 : added growable and layout (copied from Mondrian)
0.20 : fixed a bad ref in ROScatterplotLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:44'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.22'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version121: spec
	<version: '0.21' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.20 : fixed a bad ref in ROScatterplotLayout
0.21 : Renamed addNodes -> addMany: and addNode: -> add:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2011 18:47'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.23'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version122: spec
	<version: '0.22' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.21 : Renamed addNodes -> addMany: and addNode: -> add:
0.22 : Added circle layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/3/2011 16:19'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.24'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version123: spec
	<version: '0.23' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.22 : Added circle layout
0.23 : Fixed a bug related to dragging inner nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/3/2011 17:35'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.25'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version124: spec
	<version: '0.24' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.23 : Fixed a bug related to dragging inner nodes
0.24 : Cleaning. Introduced a hierarchy of elements to capture the containinment'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 10:03'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.26'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version125: spec
	<version: '0.25' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.24 : Cleaning. Introduced a hierarchy of elements to capture the containinment
0.25 : bug fixed with dragging inner nodes. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 12:16'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.27'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version126: spec
	<version: '0.26' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.25 : bug fixed with dragging inner nodes. 
0.26 : Added label'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 13:56'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version127: spec
	<version: '0.27' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.26 : Added label
0.27 : Worked on zooming'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 15:48'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.29'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version128: spec
	<version: '0.28' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.27 : Worked on zooming
0.28 : better drag and drop. Zooming works'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 16:45'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.30'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version129: spec
	<version: '0.29' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.28 : better drag and drop. Zooming works
0.29 : Added gridlayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 17:31'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.31'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version12: spec
	<version: '0.2' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.3'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version130: spec
	<version: '0.30' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.29 : Added gridlayout
0.30 : added more example, right and left click'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 18:48'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.32'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version131: spec
	<version: '0.31' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.30 : added more example, right and left click
0.31 : Worked on choice, but it does not work so far. Need to work on it'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/4/2011 19:09'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.33'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version132: spec
	<version: '0.32' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.31 : Worked on choice, but it does not work so far. Need to work on it
0.32 : bug fixed when adding elements in a container. New example added with dynamic layout update'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/7/2011 22:29'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.34'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version133: spec
	<version: '0.33' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.32 : bug fixed when adding elements in a container. New example added with dynamic layout update
0.33 : better window resize. mouse enter and mouse leave'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/8/2011 10:26'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version134: spec
	<version: '0.34' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.33 : better window resize. mouse enter and mouse leave
0.34 : fixes to make it green in a Dev'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/8/2011 15:04'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.36'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version135: spec
	<version: '0.35' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.34 : fixes to make it green in a Dev
0.35 : Preparing the animation'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/8/2011 17:22'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.37'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version136: spec
	<version: '0.36' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.35 : Preparing the animation
0.36 : added linear motion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/8/2011 17:46'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.38'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version137: spec
	<version: '0.37' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.36 : added linear motion
0.37 : Improvement of the drag and drop. But it is still buggy with multiple views'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/9/2011 12:25'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.39'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version138: spec
	<version: '0.38' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.37 : Improvement of the drag and drop. But it is still buggy with multiple views
0.38 : Added popup'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/9/2011 19:44'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version139: spec
	<version: '0.39' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.38 : Added popup
0.39 : Popup now works!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/10/2011 16:57'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.41'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version13: spec
	<version: '0.3' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.4'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version140: spec
	<version: '0.40' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.39 : Popup now works!!
0.40 : Added punch example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/12/2011 18:45'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version141: spec
	<version: '0.41' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.40 : Added punch example
0.41 : Enh of the camera, view may now be translated'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/16/2011 13:56'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version142: spec
	<version: '0.42' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.41 : Enh of the camera, view may now be translated
0.42 : cleaning of the camera and canvas business. A canvas now has solely a reference to the camera and a canvas. All but one test are green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/18/2011 11:59'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version143: spec
	<version: '0.43' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.42 : cleaning of the camera and canvas business. A canvas now has solely a reference to the camera and a canvas. All but one test are green
0.43 : Added motion as interaction. Cool!!!!!!!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2011 12:22'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version144: spec
	<version: '0.44' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.43 : Added motion as interaction. Cool!!!!!!!!
0.44 : ROView>>elementAt: works now well. Yupi!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2011 14:31'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version145: spec
	<version: '0.45' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.44 : ROView>>elementAt: works now well. Yupi!!
0.45 : '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2011 16:29'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.49'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version146: spec
	<version: '0.46' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.45 : 
0.46 : Improvement of elementAt: drag and dropping...'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 12:30'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version147: spec
	<version: '0.47' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.46 : Improvement of elementAt: drag and dropping...
0.47 : a small step toward Pharo 0.4'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 17:54'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.51'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version148: spec
	<version: '0.48' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.47 : a small step toward Pharo 0.4
0.48 : added viewstack. Two tests are yellow. Working on this'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/25/2011 12:46'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.52'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version149: spec
	<version: '0.49' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.48 : added viewstack. Two tests are yellow. Working on this
0.49 : more on motion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/29/2011 16:02'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.53'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version14: spec
	<version: '0.4' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.5'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version150: spec
	<version: '0.50' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.49 : more on motion
0.50 : all but one tests are green. Added overlappingElements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/31/2011 12:20'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version151: spec
	<version: '0.51' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.50 : all but one tests are green. Added overlappingElements
0.51 : Removed {}'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/31/2011 15:29'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.55'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version152: spec
	<version: '0.52' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.51 : Removed {}
0.52 : added asSorted: and a new example on memory profiling'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/31/2011 16:40'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.56'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version153: spec
	<version: '0.53' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.52 : added asSorted: and a new example on memory profiling
0.53 : commented edgesFrom:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/12/2011 11:24'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version154: spec
	<version: '0.54' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.53 : commented edgesFrom:
0.54 : example on latenSemanticIndexing'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/12/2011 15:43'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.58'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version155: spec
	<version: '0.55' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.54 : example on latenSemanticIndexing
0.55 : Improvement of zoom in and out. Latent Semantic Indexing is now zoomable'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/13/2011 20:20'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.59'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version156: spec
	<version: '0.56' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.55 : Improvement of zoom in and out. Latent Semantic Indexing is now zoomable
0.56 : Added new example on adding node dynamically'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/14/2011 19:47'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.60'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version157: spec
	<version: '0.57' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.56 : Added new example on adding node dynamically
0.57 : Edges can now be colored in the MondrianBuilder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/15/2011 09:26'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.61'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version158: spec
	<version: '0.58' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.57 : Edges can now be colored in the MondrianBuilder
0.58 : Martin proposed expandable nodes. His code is now in the distribution of Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/24/2011 16:19'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.62'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version159: spec
	<version: '0.59' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.58 : Martin proposed expandable nodes. His code is now in the distribution of Roassal
0.59 : Smooth node movement with expandable nodes. Check this with: ROExample new expandableNodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/28/2011 13:54'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version15: spec
	<version: '0.5' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.6'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version160: spec
	<version: '0.60' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.59 : Smooth node movement with expandable nodes. Check this with: ROExample new expandableNodes
0.60 : Added visitor and example for the highlight
0.60 : Added visitor and example on highlither'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/30/2011 10:49'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.64'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version161: spec
	<version: '0.61' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.60 : Added visitor and example on highlither
0.61 : Added comment for the latent semantic indexing example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/6/2011 09:03'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version162: spec
	<version: '0.62' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.61 : Added comment for the latent semantic indexing example
0.62 : A view can now have a title. The window uses it'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/20/2011 23:03'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version163: spec
	<version: '0.63' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '0.62 : A view can now have a title. The window uses it
0.63: Minor refactoring in camera:
0.63 : added titled: in the builder. Added the label shape in it'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/29/2012 23:38'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version164: spec
	<version: '0.64' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.63 : added titled: in the builder. Added the label shape in it
0.64 : using the builder, an edge cannot have the same from and to fields. The tree layout can now be used within an inner node'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/30/2012 18:04'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.69'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version165: spec
	<version: '0.65' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.64 : using the builder, an edge cannot have the same from and to fields. The tree layout can now be used within an inner node
0.65 : worked on the decorators. Decorator can now be changed for other. this make the treeLayout nicer'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/30/2012 18:57'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.70'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version166: spec
	<version: '0.66' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.65 : worked on the decorators. Decorator can now be changed for other. this make the treeLayout nicer
0.66 : more bug fixed on the mondrian builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/31/2012 10:10'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.71'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version167: spec
	<version: '0.67' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.66 : more bug fixed on the mondrian builder
0.67 : shape label now use a correct size'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/31/2012 18:59'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version168: spec
	<version: '0.68' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.67 : shape label now use a correct size
0.68 : Added item:actions: in the mondrian builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/31/2012 23:20'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version169: spec
	<version: '0.69' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.68 : Added item:actions: in the mondrian builder
0.69 : Cleaning in the examples and in ROCamera'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/1/2012 10:00'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version16: spec
	<version: '0.6' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.7'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version170: spec
	<version: '0.70' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.69 : Cleaning in the examples and in ROCamera
0.70 : Minor improvement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/1/2012 10:22'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version171: spec
	<version: '0.71' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.70 : Minor improvement
0.71 : FocusOnElement is done. It works well. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/1/2012 22:24'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.76'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version172: spec
	<version: '0.72' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.71 : FocusOnElement is done. It works well. 
0.72 : Cleaning the hierarchy of ROElement. ROContainingElement is almost empty by now. It will be soon removed.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/1/2012 23:29'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.77'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version173: spec
	<version: '0.73' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.72 : Cleaning the hierarchy of ROElement. ROContainingElement is almost empty by now. It will be soon removed.
0.73 : Added empty methods as future work, to make Roassal compatible with Mondrian'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/3/2012 00:14'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.78'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version174: spec
	<version: '0.74' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.73 : Added empty methods as future work, to make Roassal compatible with Mondrian
0.74 :a bit of work for the edges'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/7/2012 11:41'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.81'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version175: spec
	<version: '0.75' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.74 :a bit of work for the edges
0.75 : All tests are green. Can now have the edges between classes in Hapao. We are on the right track!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 08:59'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.82'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version176: spec
	<version: '0.76' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.75 : All tests are green. Can now have the edges between classes in Hapao. We are on the right track!!
0.76 : Added borderColor'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 15:06'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.83'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version177: spec
	<version: '0.77' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.76 : Added borderColor
0.77 : The sugiyama layout now works!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 16:18'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.84'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version178: spec
	<version: '0.78' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.77 : The sugiyama layout now works!!
0.78 : Fixed a bug when looking up inner elements. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 19:19'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.85'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version179: spec
	<version: '0.79' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.78 : Fixed a bug when looking up inner elements. 
0.79 : Hapao now can be recognized'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 20:25'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.86'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version17: spec
	<version: '0.7' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version180: spec
	<version: '0.80' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.79 : Hapao now can be recognized
0.80 : if:fillColor is now added in the builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 20:54'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.87'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version181: spec
	<version: '0.81' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.80 : if:fillColor is now added in the builder
0.81 : drag and drop of inner nodes now works much better'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/10/2012 22:07'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.88'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version182: spec
	<version: '0.82' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.81 : drag and drop of inner nodes now works much better
0.82 : Roassal now render the hapao visualization of Mondrian. And it is even faster!! (quite amazing actually. I do not understand how Mondrian could be slow on some things)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/11/2012 18:13'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.89'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version183: spec
	<version: '0.83' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.82 : Roassal now render the hapao visualization of Mondrian. And it is even faster!! (quite amazing actually. I do not understand how Mondrian could be slow on some things)
0.83 : Forwader is now implemented at the core of Roassal, and in the Mondrian builder.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/2/2012 20:19'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.90'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version184: spec
	<version: '0.84' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.83 : Forwader is now implemented at the core of Roassal, and in the Mondrian builder.
0.84 : Added a ROImage. Started to work on popupView: Need to finish'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/3/2012 09:40'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.91'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version185: spec
	<version: '0.85' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.84 : Added a ROImage. Started to work on popupView: Need to finish
0.85 : PopupView works more or less.  More work on the builder with the popupView'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/4/2012 14:01'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.92'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version186: spec
	<version: '0.86' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.85 : PopupView works more or less.  More work on the builder with the popupView
0.86 : Worked on the popupView:. A bug still remains with the edges, the lookup does not take the nesting into account .'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/4/2012 23:28'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.93'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version187: spec
	<version: '0.87' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.86 : Worked on the popupView:. A bug still remains with the edges, the lookup does not take the nesting into account .
0.87 : Defined a hierarchy for the attachPoint. AttachPoint for the suggiyama layout in the Mondrian builder. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/5/2012 12:44'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.94'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version188: spec
	<version: '0.88' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.87 : Defined a hierarchy for the attachPoint. AttachPoint for the suggiyama layout in the Mondrian builder. 
0.88 : Bug fixed for the subscriptions when handling events. The popupview in Hapao now works pretty well!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/5/2012 15:21'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version189: spec
	<version: '0.89' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.88 : Bug fixed for the subscriptions when handling events. The popupview in Hapao now works pretty well!!
0.89 : Added a find element in the mondrian builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/5/2012 16:15'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version18: spec
	<version: '0.8' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version190: spec
	<version: '0.90' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.89 : Added a find element in the mondrian builder
0.90 : Worked on the layouts (the layout is now applied when unstacking). '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2012 16:55'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.97'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version191: spec
	<version: '0.91' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.90 : Worked on the layouts (the layout is now applied when unstacking). 
0.91 : Fixed bug with multiple menu entries'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2012 18:23'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.98'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version192: spec
	<version: '0.92' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.91 : Fixed bug with multiple menu entries
0.92 :'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2012 18:33'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.99'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version193: spec
	<version: '0.93' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.92 :
0.93 : Added more example on interaction. Added few classes for the hilighting of elements.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/7/2012 09:41'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.100'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/6/2012 14:12'!
version194: spec
	<version: '0.94' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.93 : Added more example on interaction. Added few classes for the hilighting of elements.
0.94 : Added highlight'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/6/2012 14:12'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.101'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/14/2012 19:02'!
version195: spec
	<version: '0.95' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.94 : Added highlight
0.95 : Added highlight. The main view of Kai works almost. The label is left to work on.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/14/2012 19:02'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.102'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/15/2012 11:35'!
version196: spec
	<version: '0.96' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.95 : Added highlight. The main view of Kai works almost. The label is left to work on.
0.96 : Decorators are now linked listed. An element has no longer the variable decorators, but decorator instead.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/15/2012 11:35'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.103'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/15/2012 13:18'!
version197: spec
	<version: '0.97' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.96 : Decorators are now linked listed. An element has no longer the variable decorators, but decorator instead.
0.97 : Making the test more robust'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/15/2012 13:18'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.104'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/15/2012 21:06'!
version198: spec
	<version: '0.98' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.97 : Making the test more robust
0.98 : Added an example about highlighting inner nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/15/2012 21:06'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.105'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/18/2012 14:07'!
version199: spec
	<version: '0.99' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.98 : Added an example about highlighting inner nodes
0.99 : Put Morphic into a new package'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/18/2012 14:07'.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.112'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: ''!
version19: spec
	<version: '0.9' imports: #('0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: ''.
		spec timestamp: ''.
		spec package: #Roassal with: 'Roassal-AlexandreBergel.10'. ].
! !
